pub struct TlsStream<S>(/* private fields */);Expand description
A wrapper around an underlying raw stream which implements the TLS or SSL protocol.
A TlsStream<S> represents a handshake that has been completed successfully
and both the server and the client are ready for receiving and sending
data. Bytes read from a TlsStream are decrypted from S and bytes written
to a TlsStream are encrypted when passing through to S.
Implementations